$wnd.rstudio.runAsyncCallback9("function Gps(a){this.a=a}\nfunction mns(a){a.J.d7b();AYg(a.j.o)}\nfunction kns(a){Ipq(a.j);Xxi(a.a,bns.ljc(),'loadhistory')}\nfunction lns(a){Ipq(a.j);ayi(a.a,bns.pjc(),'.Rhistory',false,'savehistory')}\nfunction Cps(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=jqs(a.a.b.a);Liq(a.a,a.a.a)}switch(a.c){case 1:a.a.a.J.b7b();break;case 2:a.a.a.J.c7b();break;case 3:kns(a.a.a);break;case 4:lns(a.a.a);break;case 5:mns(a.a.a);break;case 6:a.a.a.J.e7b();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].ln()}}\nvar bIB='Load History',cIB='Save History As';qNd(4024,1,S6A);_.ljc=function qos(){return bIB};_.pjc=function uos(){return cIB};qNd(4023,1,S6A);_.ljc=function Los(){return bIB};_.pjc=function Pos(){return cIB};qNd(4022,1,S6A);_.ljc=function eps(){return \"Chargement de l'historique\"};_.pjc=function ips(){return \"Enregistrer l'historique en tant que\"};qNd(516,1,G8y);_.jn=function Fps(){Cps((new Gps(this)).a)};qNd(7395,1,EAy,Gps);_.ln=function Hps(){Cps(this.a)};var iCc=hAe(7395);xky(hm)(9);\n//# sourceURL=rstudio-9.js\n")
