$wnd.rstudio.runAsyncCallback15("function hzq(){}\nfunction fzq(a){this.a=a}\nfunction kzq(a){this.a=a}\nfunction mzq(a){this.a=a}\nfunction Cyq(a){this.a=a}\nfunction qAq(a){this.a=a}\nfunction QUi(a){this.a=a}\nfunction Ayq(a){Zyi.call(this,a)}\nfunction hyq(a){tyq(a,new kzq(a))}\nfunction nyq(a){a.J.d7b();gn((_m(),$m),new Cyq(a))}\nfunction myq(a){mTi(a.b,byq.U7b(),byq.U7b(),new mzq(a))}\nfunction oyq(a){yVt(a.n,new azq(a,LFy,false),new czq,Jlz)}\nfunction lyq(a){yVt(a.n,new fzq(a),new hzq,byq.N7b())}\nfunction qyq(a,b){U1h(a.d,new m8q(b,true,true),false)}\nfunction xTi(a,b){JSi();(MPe(b),b)&&syq(a.a,_JB,'')}\nfunction Eyq(a,b){vuf();this.a=a;this.b=b;xuf.call(this)}\nfunction jzq(a,b){qyq(a.a,'devtools::load_all(\"'+b+'\")')}\nfunction $um(a,b){xzm(a,Epz,'devtools_load_all_path',new wL,b)}\nfunction tyq(a,b){a.c!=null?jzq(b,a.c):$um(a.j,new Eyq(a,b))}\nfunction mTi(a,b,c,d){ZSi(a,b,c,pVi(IVo(a.i.b),'roxygen'),MSi(a,'roxygen'),false,new QUi(d))}\nfunction eyq(a,b){var c,d;yLi(a.q.g,null);d=b.outputs;for(c=0;c<d.length;c++)zxq(a.q,d[c]);b.errors.length>0&&yxq(a.q,b.errors_base_dir,b.errors,false,0,true,b.type);b.running?o9e(a.a.Vj,true,false):xLi(a.q.g);PSg(a.q.g.c.c)}\nfunction mAq(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=CCq(a.a.b.a);Liq(a.a,a.a.a)}switch(a.c){case 1:eyq(a.a.a,a.b[0]);break;case 2:a.a.a.J.b7b();break;case 3:a.a.a.J.c7b();break;case 4:syq(a.a.a,tUA,'');break;case 5:syq(a.a.a,'build-binary-package','');break;case 6:syq(a.a.a,'build-full','');break;case 7:syq(a.a.a,'build-incremental','');break;case 8:syq(a.a.a,'build-source-package','');break;case 9:syq(a.a.a,'check-package','');break;case 10:syq(a.a.a,'clean-all','');break;case 11:lyq(a.a.a);break;case 12:myq(a.a.a);break;case 13:nyq(a.a.a);break;case 14:oyq(a.a.a);break;case 15:zAm(a.a.a.j,new Ayq((cyq(),byq).d8b()));break;case 16:syq(a.a.a,'test-package','');break;case 19:a.a.a.J.e7b();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].ln()}}\nvar _JB='roxygenize-package',aKB='Error Terminating Build',bKB='Unable to terminate build. Please try again.',cKB='Building package documentation',dKB='Terminating Build...';qNd(2331,1,zAy,QUi);_.pw=function RUi(a){xTi(this.a,a)};var Pyb=hAe(2331);qNd(8191,394,{},Ayq);_.$m=function Byq(a){(MPe(a),a)||kyi(3,(cyq(),byq).Q7b(),byq.R7b()).aV()};var dic=hAe(8191);qNd(8192,1,EAy,Cyq);_.ln=function Dyq(){PSg(this.a.q.g.c.c)};var eic=hAe(8192);qNd(8193,54,{},Eyq);_.AA=function Fyq(a){this.a.c=a;jzq(this.b,this.a.c)};var fic=hAe(8193);qNd(8184,1,EAy,fzq);_.ln=function gzq(){hyq(this.a)};var vic=hAe(8184);qNd(8185,1,EAy,hzq);_.ln=function izq(){cyq()};var wic=hAe(8185);qNd(8183,1,zAy,kzq);_.pw=function lzq(a){jzq(this,a)};var xic=hAe(8183);qNd(8186,1,EAy,mzq);_.ln=function nzq(){syq(this.a,_JB,'')};var yic=hAe(8186);qNd(248,1,G8y);_.jn=function pAq(){mAq((new qAq(this)).a)};qNd(7460,1,EAy,qAq);_.ln=function rAq(){mAq(this.a)};var Vic=hAe(7460);qNd(5602,1,vUA);_.Q7b=function DAq(){return aKB};_.R7b=function EAq(){return bKB};_.U7b=function HAq(){return cKB};_.d8b=function SAq(){return dKB};qNd(5601,1,vUA);_.Q7b=function cBq(){return aKB};_.R7b=function dBq(){return bKB};_.U7b=function gBq(){return cKB};_.d8b=function rBq(){return dKB};qNd(5600,1,vUA);_.Q7b=function DBq(){return 'Erreur de fin de construction'};_.R7b=function EBq(){return 'Impossible de terminer la construction. Veuillez r\\xE9essayer.'};_.U7b=function HBq(){return 'Documentation du paquet de construction'};_.d8b=function SBq(){return 'Terminer la construction...'};xky(hm)(15);\n//# sourceURL=rstudio-15.js\n")
