$wnd.rstudio.runAsyncCallback3("function Zjq(a){this.a=a}\nfunction _jq(a){this.a=a}\nfunction ikq(a){this.a=a}\nfunction qBf(a,b){var c;for(c=0;c<a.q.a.length;c++){if(q6d(a.q,c).zNc==b){oHf(a.t,gBe(c));break}}}\nfunction Wjq(a){var b;b=Xjq(a,(Tjq(),Sjq).v7b(),a.b,$rp(a.c.c));b||Xjq(a,Sjq.r7b(),a.a,Yrp(a.c.c))}\nfunction Yjq(a,b){this.c=a;this.b=$rp(a.c).XXb();this.a=Yrp(a.c).XXb();xi(b,new Zjq(this),cE?cE:(cE=new xB))}\nfunction Ujq(a,b,c){var d;d=Icq(a.b.a);vBf(d,P_p(U2j((LKh(),KKh).a)));!!b&&qBf(d,b);BBf(d,c);Mnf(d,true);new Yjq(a,d);(hSh()||!!$wnd.remoteDesktop)&&pSh()}\nfunction Xjq(a,b,c,d){if(fO(c)!==fO(d.XXb())&&fO(d.Zs())!==fO(d.XXb())){Y1e(2,(Tjq(),Sjq).s7b(),Sjq.t7b(b,d.XXb(),d.Zs()),new _jq(a),true);return true}else{return false}}\nfunction ekq(a){try{if(a.c<0)return;!a.a.a&&(a.a.a=Isq(a.a.b.a));switch(a.c){case 1:Ujq(a.a.a,null,true);break;case 2:Ujq(a.a.a,a.b[0],Mze(a.b[1]));}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].ln()}}\nvar _GB='LaTeX typesetting',aHB='Project Option Unchanged',bHB='You changed the global option for ',cHB=', however the current project is still configured to use ',dHB='weaving Rnw files';qNd(2993,1,{},Yjq);var Oec=hAe(2993);qNd(2994,1,hyy,Zjq);_.wo=function $jq(a){Wjq(this.a)};var Mec=hAe(2994);qNd(2995,1,eEy,_jq);_.ln=function akq(){T8e(this.a.c.a.kh)};var Nec=hAe(2995);qNd(637,1,G8y);_.jn=function hkq(){ekq((new ikq(this)).a)};qNd(3060,1,EAy,ikq);_.ln=function jkq(){ekq(this.a)};var Pec=hAe(3060);qNd(4138,1,xTA);_.r7b=function fpq(){return _GB};_.s7b=function gpq(){return aHB};_.t7b=function hpq(a,b,c){return bHB+a+cAy+b+cHB+c+'.\\\\n\\\\nDo you want to edit the options for the current project as well?'};_.v7b=function jpq(){return dHB};qNd(4139,1,xTA);_.r7b=function rpq(){return _GB};_.s7b=function spq(){return aHB};_.t7b=function tpq(a,b,c){return bHB+a+cAy+b+cHB+c+'.\\n\\nDo you want to edit the options for the current project as well?'};_.v7b=function vpq(){return dHB};qNd(4137,1,xTA);_.r7b=function Dpq(){return 'Mise en page LaTeX'};_.s7b=function Epq(){return 'Option du projet inchang\\xE9e'};_.t7b=function Fpq(a,b,c){return \"Vous avez chang\\xE9 l'option globale de \"+a+' en '+b+', mais le projet actuel est toujours configur\\xE9 pour utiliser '+c+'.\\n\\nVoulez-vous \\xE9galement modifier les options du projet actuel ?'};_.v7b=function Hpq(){return 'Tisse le fichiers Rnw'};xky(hm)(3);\n//# sourceURL=rstudio-3.js\n")
